@@ -20,6 +20,8 @@ Example Output to stdout:
   
 """
 
+# this could be an igneous CLI command
+
 import sys
 import os
 
@@ -28,15 +30,16 @@ from tqdm import tqdm
 from cloudvolume.lib import max2
 from cloudvolume import CloudVolume, Storage, Bbox
 
+from cloudfiles import CloudFiles
+
 layer_path = sys.argv[1]
 
 cv = CloudVolume(layer_path)
+cf = CloudFiles(layer_path)
 
 bboxes = []
-
-with Storage(layer_path) as stor:
-  for filename in tqdm(stor.list_files(prefix=cv.key), desc="Computing Bounds"):
-    bboxes.append( Bbox.from_filename(filename) )
+for filename in tqdm(cf.list(prefix=cv.key), desc="Computing Bounds"):
+  bboxes.append( Bbox.from_filename(filename) )
 
 bounds = Bbox.expand(*bboxes)
 chunk_size = reduce(max2, map(lambda bbox: bbox.size3(), bboxes))
